<?php
/**
 * Plugin Name: BuddyCircles :- BuddyPress User Circles
 * Version: 1.3.2
 * Plugin URI: https://buddydev.com/plugins/buddycircles/
 * Description: Let your users create circle of users.
 * Author: BuddyDev
 * Author URI: https://buddydev.com/
 * Requires PHP: 5.3
 * License:      GPL2
 * License URI:  https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain:  buddycircles
 * Domain Path:  /languages
 *
 * @package BuddyCircles
 **/

use PressThemes\BuddyCircles\Bootstrap\Autoloader;
use PressThemes\BuddyCircles\Bootstrap\Bootstrapper;
use PressThemes\BuddyCircles\Schema\Schema;

// No direct access over web.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Class Buddy_Circles_Helper
 *
 * @property-read string                $path absolute path to the plugin directory.
 * @property-read string                $url absolute url to the plugin directory.
 * @property-read string                $basename plugin base name.
 * @property-read string                $version plugin version.
 */
class BuddyCircles {
	/**
	 * Plugin Version.
	 *
	 * @var string
	 */
	private $version = '1.3.2';
	/**
	 * Class instance
	 *
	 * @var BuddyCircles
	 */
	private static $instance = null;

	/**
	 * Plugin absolute directory path
	 *
	 * @var string
	 */
	private $path;

	/**
	 * Plugin absolute directory url
	 *
	 * @var string
	 */
	private $url;

	/**
	 * Plugin Basename.
	 *
	 * @var string
	 */
	private $basename;

	/**
	 * Protected properties. These properties are inaccessible via magic method.
	 *
	 * @var array
	 */
	private static $protected = array( 'instance' );

	/**
	 * BuddyDev_Circles_Helper constructor.
	 */
	private function __construct() {
		$this->bootstrap();
	}

	/**
	 * Get Singleton Instance
	 *
	 * @return BuddyCircles
	 */
	public static function get_instance() {

		if ( is_null( self::$instance ) ) {
			self::$instance = new self();
		}

		return self::$instance;
	}

	/**
	 * Bootstrap the core.
	 */
	private function bootstrap() {

		// Setup general properties.
		$this->path     = plugin_dir_path( __FILE__ );
		$this->url      = plugin_dir_url( __FILE__ );
		$this->basename = plugin_basename( __FILE__ );

		// Load autoloader.
		require_once $this->path . 'src/bootstrap/class-autoloader.php';

		$autoloader = new Autoloader( 'PressThemes\\BuddyCircles\\', __DIR__ . '/src/' );

		spl_autoload_register( $autoloader );

		register_activation_hook( __FILE__, array( $this, 'on_activation' ) );
		register_deactivation_hook( __FILE__, array( $this, 'on_deactivation' ) );

		// Drop tables on uninstall.
		//register_uninstall_hook( __FILE__, array( 'Schema', 'drop' ) );

		Bootstrapper::boot();
	}

	/**
	 * On activation create table
	 */
	public function on_activation() {
		Schema::create();

		if ( ! get_option( 'bcircles_settings' ) ) {
			require_once $this->path . 'src/core/circle-functions.php';
			update_option( 'bcircles_settings', bcircles_get_default_options() );
		}
	}


	/**
	 * On deactivation. Do cleanup if needed.
	 */
	public function on_deactivation() {
		// do cleanup.
		// delete_option( 'bcircles_settings' );
	}

	/**
	 * Magic method for accessing property as readonly(It's a lie, references can be updated).
	 *
	 * @param string $name property name.
	 *
	 * @return mixed|null
	 */
	public function __get( $name ) {

		if ( ! in_array( $name, self::$protected, true ) && property_exists( $this, $name ) ) {
			return $this->{$name};
		}

		return null;
	}
}

/**
 * Helper to access singleton instance
 *
 * @return BuddyCircles
 */
function buddycircles() {
	return BuddyCircles::get_instance();
}

buddycircles();

