<?php
/**
 * Assets Loader
 *
 * @package    BuddyCircles
 * @subpackage Bootstrap
 * @copyright  Copyright (c) 2018, Brajesh Singh
 * @license    https://www.gnu.org/licenses/gpl.html GNU Public License
 * @author     Brajesh Singh, Ravi Sharma
 * @since      1.0.0
 */

namespace PressThemes\BuddyCircles\Bootstrap;

if ( ! defined( 'ABSPATH' ) ) {
	exit( 0 );
}

/**
 * Assets Loader.
 */
class Assets_Loader {

	/**
	 * Data to be send as localized js.
	 *
	 * @var array
	 */
	private $data = array();

	/**
	 * Boot itself
	 */
	public static function boot() {
		$self = new self();
		$self->setup();
	}

	/**
	 * Setup
	 */
	public function setup() {
		add_action( 'bp_enqueue_scripts', array( $this, 'load_assets' ) );
	}

	/**
	 * Load plugin assets
	 */
	public function load_assets() {
		$this->register();
		$this->enqueue();
	}

	/**
	 * Register assets.
	 */
	public function register() {
		$this->register_vendors();
		$this->register_core();
	}

	/**
	 * Load assets.
	 */
	public function enqueue() {
		wp_enqueue_style( 'buddycircles' );

		if ( is_user_logged_in() ) {
			wp_enqueue_style( 'webui-popover' );

			wp_enqueue_script( 'buddycircles' );
			$data = (array) apply_filters( 'bcircles_localized_Script_data', $this->data );
			wp_localize_script( 'buddycircles', 'BuddyCircles', $data );
		}
	}

	/**
	 * Register vendor scripts.
	 */
	private function register_vendors() {
		$bc = buddycircles();
		$url           = $bc->url;
		$version       = $bc->version;

		wp_register_style( 'webui-popover', $url . 'assets/vendors/webui/jquery.webui-popover.css', false, $version );
		wp_register_script( 'webui-popover', $url . 'assets/vendors/webui/jquery.webui-popover.js', array( 'jquery' ), $version );
	}

	/**
	 * Register core assets.
	 */
	private function register_core() {

		$bc = buddycircles();
		$url           = $bc->url;
		$version       = $bc->version;

		wp_register_style( 'buddycircles', $url . 'assets/css/buddycircles.css', false, $version );
		wp_register_script( 'buddycircles', $url . 'assets/js/buddycircles.js', array( 'webui-popover', 'jquery', 'underscore' ), $version );

		$circles = bcircles_get_circle_objects( bcircles_get_user_circles( bp_loggedin_user_id(), true, true ) );

		$circle_plain_objects = array();
		foreach ( $circles as $circle ) {
			$circle_plain_objects[ $circle->id ] = $circle->as_plain();
		}

		$this->data = array(
			'circles'             => array_values( $circle_plain_objects ),
			'circlesModalTitle'   => __( 'Choose Circle', 'buddycircles' ),
			'nonce'               => wp_create_nonce( 'bcircles_action' ),
			'confirmMessage'      => __( 'Are you sure you want to delete the circle?', 'buddycircles' ),
			'addToCircleLabel'    => __( 'Add to Circle', 'buddycircles' ),
			'updateLabelOnChange' => 1,
		);
	}
}
