<?php
/**
 * Bootstrapper. Initializes the plugin.
 *
 * @package    BuddyCircles
 * @subpackage Bootstrap
 * @copyright  Copyright (c) 2018, Brajesh Singh
 * @license    https://www.gnu.org/licenses/gpl.html GNU Public License
 * @author     Brajesh Singh
 * @since      1.0.0
 */

namespace PressThemes\BuddyCircles\Bootstrap;

use PressThemes\BuddyCircles\Admin\Admin_Settings;
use PressThemes\BuddyCircles\Handlers\Ajax_Request_Handler;
use PressThemes\BuddyCircles\Handlers\Hooks_Helper;
use PressThemes\BuddyCircles\Handlers\Actions_Handler;
use PressThemes\BuddyCircles\Core\BCircles_BuddyBoss_Helper;

// No direct access.
if ( ! defined( 'ABSPATH' ) ) {
	exit( 0 );
}

/**
 * Bootstrapper.
 */
class Bootstrapper {

	/**
	 * Setup the bootstrapper.
	 */
	public static function boot() {
		$self = new self();
		$self->setup();
	}

	/**
	 * Bind hooks
	 */
	private function setup() {
		add_action( 'bp_loaded', array( $this, 'load' ), 1 );
		add_action( 'plugins_loaded', array( $this, 'load_admin' ), 9996 ); // pt settings 1.0.4.
		add_action( 'bp_loaded', array( $this, 'load_translations' ), 0 );
	}

	/**
	 * Load core functions/template tags.
	 * These are non auto loadable constructs.
	 */
	public function load() {
		$path = buddycircles()->path;

		$files = array(
			'src/core/circle-functions.php',
			'src/core/circle-compat-functions.php',
			'src/core/circle-template.php',
			'src/core/circle-templates.php',
			'src/core/circle-cache-functions.php',
			'src/permissions/circle-permissions.php',
		);

		foreach ( $files as $file ) {
			require_once $path . $file;
		}

		Hooks_Helper::boot();
		Ajax_Request_Handler::boot();
		Actions_Handler::boot();
		Assets_Loader::boot();

		if ( defined( 'BP_PLATFORM_VERSION' ) ) {
			BCircles_BuddyBoss_Helper::boot();
		}
	}

	/**
	 * Load pt-settings framework
	 */
	public function load_admin() {

		if ( function_exists( 'buddypress' ) && is_admin() && ! defined( 'DOING_AJAX' ) ) {
			require_once buddycircles()->path . 'src/admin/pt-settings/pt-settings-loader.php';
			Admin_Settings::boot();
		}
	}

	/**
	 * Load translations.
	 */
	public function load_translations() {
		load_plugin_textdomain( 'buddycircles', false, basename( buddycircles()->path ) . '/languages' );
	}
}
