<?php
/**
 * Short Description
 *
 * @package    bp3.0_dev
 * @subpackage ${NAMESPACE}
 * @copyright  Copyright (c) 2018, Brajesh Singh
 * @license    https://www.gnu.org/licenses/gpl.html GNU Public License
 * @author     Brajesh Singh
 * @since      1.0.0
 */

use PressThemes\BuddyCircles\Models\Circle;
use PressThemes\BuddyCircles\Schema\Schema;

function bcircles_cache_circles( $circle_ids, $cache_count = false, $cache_members = false ) {

	_bcircles_cache_circles( $circle_ids );

	if ( $cache_count ) {
		_bcircle_cache_count( $circle_ids );
	}

	if ( $cache_members ) {
		_bcircles_cache_users( $circle_ids );
	}
}
function _bcircles_cache_circles( $circle_ids  ) {
	global $wpdb;
	$non_cached_ids = array();
	foreach ( $circle_ids as $circle_id ) {
		if( false === wp_cache_get( "circle_{$circle_id}", 'bcircles' ) ) {
			$non_cached_ids [] = $circle_id;
		}
	}

	if ( empty( $non_cached_ids ) ) {
		return;
	}

	$list = '(' . join( ',', $non_cached_ids ) . ')';

	$table = Schema::table( 'circles' );

	$results = $wpdb->get_results( "SELECT * FROM {$table} WHERE id IN {$list}" );
	foreach ( $results as $result ) {
		wp_cache_set( "circle_{$result->id}", $result, 'bcircles' );
	}

}

function _bcircle_cache_count( $circle_ids ) {
	global $wpdb;

	$non_cached_ids = array();
	foreach ( $circle_ids as $circle_id ) {
		if( false === wp_cache_get( "circle_{$circle_id}_ucount", 'bcircles' ) ) {
			$non_cached_ids [] = $circle_id;
		}
	}

	if ( empty( $non_cached_ids ) ) {
		return;
	}


	$list = '(' . join( ',', $non_cached_ids ) . ')';

	$table = Schema::table( 'members' );

	$results = $wpdb->get_results( "SELECT circle_id, COUNT(circle_id) as total FROM {$table}  WHERE circle_id IN {$list} GROUP By circle_id " );
	foreach ( $results as $result ) {
		// cache count
		wp_cache_set( "circle_{$result->circle_id}_ucount", $result->total, 'bcircles' );
	}

}

function _bcircles_cache_users( $circle_ids ) {
	global $wpdb;


	$non_cached_ids = array();
	foreach ( $circle_ids as $circle_id ) {
		if( false === wp_cache_get( "circle_{$circle_id}_users", 'bcircles' ) ) {
			$non_cached_ids [] = $circle_id;
		}
	}

	if ( empty( $non_cached_ids ) ) {
		return;
	}

	$list = '(' . join( ',', $non_cached_ids ) . ')';

	$table = Schema::table( 'members' );

	$results = $wpdb->get_results( "SELECT user_id, circle_id FROM {$table} WHERE circle_id IN {$list}" );

	$circle_users = array();

	foreach ( $results as $result ) {
		if ( empty( $circle_users[ $result->circle_id ] ) ) {
			$circle_users[ $result->circle_id ] = array();
		}
		$circle_users[ $result->circle_id ][] = $result->user_id;
	}

	foreach ( $non_cached_ids as $circle_id ) {
		$users = isset( $circle_users[$circle_id] ) ? $circle_users[$circle_id]: array();
		wp_cache_set( "circle_{$circle_id}_users", $users, 'bcircles' );
	}
}

/**
 * Add circle to cache.
 *
 * @param int|Circle $circle id or object.
 */
function bcircles_cache_circle( $circle ) {
	if ( empty( $circle ) ) {
		return;
	}

	wp_cache_set( "circle_{$circle->id}", $circle, 'bcircles' );
}

/**
 * remove circle from cache.
 *
 * @param $circle
 */
function bcircles_circle_cache_prune( $circle ) {

	if ( is_object( $circle ) ) {
		$circle_id = $circle->id;
		$user_id   = $circle->user_id;
	} else {
		$circle_id = $circle;
		$user_id   = 0;
	}

	wp_cache_delete( "circle_{$circle_id}", 'bcircles' );
	wp_cache_delete( "circle_{$circle_id}_ucount", 'bcircles' );
	wp_cache_delete( "circle_{$circle_id}_users", 'bcircles' );

	wp_cache_delete( "user_circles_{$user_id}", 'bcircles' );
	wp_cache_delete( "user_{$user_id}_all_circles_users", 'bcircles' );
}

/**
 * Get non cached items.
 *
 * @param array $item_ids ID list.
 * @param string $cache_group The cache group to check against.
 *
 * @return array
 */
function bcircles_get_non_cached_ids( $item_ids, $cache_group ) {
	$uncached = array();

	foreach ( $item_ids as $item_id ) {
		$item_id = (int) $item_id;
		if ( false === wp_cache_get( $item_id, $cache_group ) ) {
			$uncached[] = $item_id;
		}
	}

	return $uncached;
}


