<?php
/**
 * Compat functions
 *
 * @package    BuddyCircles
 * @subpackage Core
 * @copyright  Copyright (c) 2023, Brajesh Singh
 * @license    https://www.gnu.org/licenses/gpl.html GNU Public License
 * @author     Brajesh Singh, Ravi Sharma
 * @since      1.0.0
 */

// Exit if accessed directly.
defined( 'ABSPATH' ) || exit;

/**
 * Retrieves displayed user url.
 *
 * @param array $path_chunks {
 *     An array of arguments. Optional.
 *
 *     @type string $single_item_component        The component slug the action is relative to.
 *     @type string $single_item_action           The slug of the action to perform.
 *     @type array  $single_item_action_variables An array of additional information about the action to perform.
 * }
 *
 * @return string The displayed user URL.
 */
function bcircles_get_displayed_user_url( $path_chunks = array() ) {

	if ( bcircles_is_bp_rewrite_enabled() ) {
		return bp_displayed_user_url( bp_members_get_path_chunks( $path_chunks ) );
	}

	$user_url = bp_displayed_user_domain();

	if ( $path_chunks ) {
		$action_variables = end( $path_chunks );
		if ( is_array( $action_variables ) ) {
			array_pop( $path_chunks );
			$path_chunks = array_merge( $path_chunks, $action_variables );
		}

		$user_url = trailingslashit( $user_url ) . trailingslashit( implode( '/', $path_chunks ) );
	}

	return $user_url;
}

/**
 * Retrieves logged-in user url.
 *
 * @param array $path_chunks {
 *     An array of arguments. Optional.
 *
 *     @type string $single_item_component        The component slug the action is relative to.
 *     @type string $single_item_action           The slug of the action to perform.
 *     @type array  $single_item_action_variables An array of additional information about the action to perform.
 * }
 *
 * @return string The logged-in user URL.
 */
function bcircles_get_loggedin_user_url( $path_chunks = array() ) {

	if ( bcircles_is_bp_rewrite_enabled() ) {
		return bp_loggedin_user_url( bp_members_get_path_chunks( $path_chunks ) );
	}

	$user_url = bp_loggedin_user_domain();

	if ( $path_chunks ) {
		$action_variables = end( $path_chunks );
		if ( is_array( $action_variables ) ) {
			array_pop( $path_chunks );
			$path_chunks = array_merge( $path_chunks, $action_variables );
		}

		$user_url = trailingslashit( $user_url ) . trailingslashit( implode( '/', $path_chunks ) );
	}

	return $user_url;
}
