<?php
/**
 * Template functions
 *
 * @package BuddyCircles
 */

// Exit if file accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Render button to add circle
 *
 * @param int $user_id User id.
 *
 * @return string
 */
function bcircles_add_to_circle_button( $user_id ) {

	if ( empty( $user_id ) ) {
		return;
	}

	$output = bcircles_get_add_to_circle_button( $user_id );
	if ( $output ) {
		echo '<div class="circle-button generic-button">' . $output . '</div>';
	}
}

/**
 * Get button to add circle
 *
 * @param int $user_id User id.
 *
 * @return string
 */
function bcircles_get_add_to_circle_button( $user_id, $label = '', $atts = array() ) {

	$logged_id = bp_loggedin_user_id();

	if ( ! $user_id || ! $logged_id || $user_id == $logged_id ) {
		return '';
	}

	$count = 0;

	if ( bcircles_has_user_in_circles( $logged_id, $user_id ) ) {
		$count          = bcircles_get_circle_count_between_users( $logged_id, $user_id );
		$label_btn_text = sprintf( _nx( '1 Circle', '%d Circles', $count, 'User circle count in buttons', 'buddycircles' ), $count );
	} else {
		$label_btn_text = __( 'Add to Circle', 'buddycircles' );
	}

	$circle_member_type = bcircles_get_option( 'circle_member_type' );

	if ( $count == 0 && 'friends_only' == $circle_member_type && ! friends_check_friendship( $logged_id, $user_id ) ) {
		return '';
	}

	if ( $label ) {
		$label_btn_text = $label;
	}

	$attributes = '';
	if ( $atts ) {
		foreach ( $atts as $prop => $value ) {
			$attributes .= sprintf( " {$prop}='%s'", esc_attr( $value ) );
		}
	}

	return sprintf( "<a href='#' class='bcircles-add-circle' data-user-id='%d' data-singular='%s' data-plural='%s' data-count='%d' data-engaged-circles='%s' %s >%s </a>", $user_id, __( 'Circle', 'buddycircles' ), __( 'Circles', 'buddycircles' ), $count, join( ',', bcircles_get_circles_between_users( $logged_id, $user_id ) ), $attributes, $label_btn_text );
}

/**
 * Get delete link
 *
 * @param int $circle_id Circle id.
 *
 * @return string
 */
function bcircles_get_circle_delete_link( $circle_id ) {

	if ( ! is_super_admin() && ! bp_is_my_profile() ) {
		return '';
	}

	$circle = bcircles_get_circle( $circle_id );

	if ( empty( $circle->id ) || ! bcircles_user_can_delete_circle( get_current_user_id(), $circle ) ) {
		return '';
	}

	$link = "<div class='generic-button circle-button'><a href='#' data-circle-id='". $circle->id ."' class='btn button bcircles-circle-delete'>".__( 'Delete', 'buddycircles' ) . "</a></div>";

	return $link;
}