<?php
/**
 * Short Description
 *
 * @package    bp3.0_dev
 * @subpackage ${NAMESPACE}
 * @copyright  Copyright (c) 2018, Brajesh Singh
 * @license    https://www.gnu.org/licenses/gpl.html GNU Public License
 * @author     Brajesh Singh
 * @since      1.0.0
 */

/**
 * Check if my circle activity screen
 *
 * @return bool
 */
function bcircles_is_my_circle_activity() {

	$slug = bcircles_get_circle_slug();

	if ( bp_is_my_profile() && bp_is_activity_component() && bp_is_current_action( $slug ) ) {
		return true;
	}

	return false;
}

/**
 * Check weather is current page a circles page or not
 *
 * @return bool
 */
function bcircles_is_circles_page() {
	$parent_component = bcircles_get_parent_component_slug();

	if ( $parent_component && bp_is_current_component( $parent_component ) && bp_is_current_action( bcircles_get_circle_slug() ) ) {
		return true;
	}

	return bp_is_current_component( 'circle' );
}

/**
 * Check if circle component
 *
 * @return bool
 */
function bcircles_is_circle_component() {
	return bp_is_current_component( bcircles_get_circle_slug() );
}


/**
 * Get circle slug
 *
 * @return string
 */
function bcircles_get_circle_slug() {
	$slug = bcircles_get_option( 'slug' );
	return $slug;
}

/**
 * Get circle url
 *
 * @return string
 */
function bcircles_get_circles_screen_url() {

	$user_domain      = bp_is_user() ? bp_displayed_user_domain() : bp_loggedin_user_domain();
	$parent_component = bcircles_get_parent_component_slug();

	if ( $parent_component ) {
		return trailingslashit( $user_domain . $parent_component . '/' . bcircles_get_circle_slug() );
	}

	return trailingslashit( $user_domain . bcircles_get_circle_slug() );
}

/**
 * Get single circle page url
 *
 * @param int $circle_id Circle id.
 *
 * @return string
 */
function bcircles_get_single_circle_screen_url( $circle_id ) {
	$parent_component   = bcircles_get_parent_component_slug();
	$circles_screen_url = bcircles_get_circles_screen_url();

	if ( $parent_component ) {
		return trailingslashit( $circles_screen_url . $circle_id );
	}

	return trailingslashit( $circles_screen_url . 'circle/' . $circle_id );
}

/**
 * Circle privacy drop down
 *
 * @param array $args Args.
 */
function bcircles_privacy_dropdown( $args = array() ) {
	$default = array(
		'name'     => 'privacy',
		'selected' => 'public',
	);

	$args = wp_parse_args( $args, $default );

	$enabled_privacies = bcircles_get_option( 'privacy' );
	$privacies         = bcircles_get_privacies();

	?>
	<select class="bcircles-privacy-dropdown" name="<?php esc_attr_e( $args['name'] ); ?>">
		<?php foreach ( $enabled_privacies as $privacy ) : ?>
			<option value="<?php esc_attr_e( $privacy ) ?>" <?php selected( $privacy, $args['selected'] ) ?>><?php echo $privacies[$privacy]; ?></option>
		<?php endforeach; ?>
	</select>
	<?php
}

/**
 * Notification format for local notifications.
 *
 * @param string $action action of notification.
 * @param int    $item_id primary item id.
 * @param int    $secondary_item_id secondary item id.
 * @param int    $total_items total items.
 * @param string $format format.
 * @param int    $notification_id Notification id.
 *
 * @return mixed
 */
function bcircles_format_notifications( $action, $item_id, $secondary_item_id, $total_items, $format, $notification_id ) {

	$text = '';

	$link = bp_get_notifications_permalink( get_current_user_id() );

	$link = add_query_arg( array(
		'action'          => 'bcircles_clear',
		'nonce'           => wp_create_nonce( 'bcircles_clear_notification' ),
		'notification_id' => $notification_id,
	), $link );

	if ( 'user_added' == $action ) {
		$text = sprintf( __( '%s has added you in his circle', 'buddycircles' ), bp_core_get_user_displayname( $secondary_item_id ) );
	} elseif ( 'user_deleted' == $action ) {
		$text = sprintf( __( '%s has deleted you from his circle', 'buddycircles' ), bp_core_get_user_displayname( $secondary_item_id ) );
	}

	if ( 'string' == $format ) {
		$return = '<a href="' . esc_url( $link ) . '">' . esc_html( $text ) . '</a>';
	} else {
		$return = array(
			'text' => $text,
			'link' => $link,
		);
	}

	return $return;
}
