<?php
/**
 * File description.
 *
 * @package    PressThemes\BuddyCircles
 * @subpackage Core
 * @copyright  Copyright (c) 2021, BuddyDev
 * @license    https://www.gnu.org/licenses/gpl.html GNU Public License
 * @author     Brajesh Singh, Ravi Sharma
 * @since      1.0.0
 */

namespace PressThemes\BuddyCircles\Core;

// Exit if access directly.
defined( 'ABSPATH' ) || exit;

/**
 * Class BCircles_BuddyBoss_Helper
 */
class BCircles_BuddyBoss_Helper {

	/**
	 * Class instance
	 *
	 * @var BCircles_BuddyBoss_Helper
	 */
	private static $instance = null;

	/**
	 * Returns class instance
	 *
	 * @return BCircles_BuddyBoss_Helper
	 */
	public static function boot() {

		if ( is_null( self::$instance ) ) {
			self::$instance = new self();
		}

		return self::$instance;
	}

	/**
	 * BCircles_BuddyBoss_Helper constructor.
	 */
	private function __construct() {
		add_action( 'before_circle_users_loop', array( $this, 'attach_filters' ) );
		add_action( 'after_circle_users_loop', array( $this, 'remove_filters' ) );
	}

	/**
	 * Attaches filters
	 */
	public function attach_filters() {
		add_filter( 'bp_displayed_user_id', array( $this, 'modify_displayed_user_id' ), 11 );
	}

	/**
	 * Removes filters
	 */
	public function remove_filters() {
		remove_filter( 'bp_displayed_user_id', array( $this, 'modify_displayed_user_id' ), 11 );
	}

	/**
	 * Get member id.
	 *
	 * @param int $id Member id.
	 *
	 * @return int
	 */
	public function modify_displayed_user_id( $id ) {

		if ( bcircles_is_circles_page() ) {
			return bp_get_member_user_id();
		}

		return $id;
	}
}
