<?php
/**
 * Hooks helper class
 *
 * @package BuddyCircles
 * @subpackage Handlers
 */

namespace PressThemes\BuddyCircles\Handlers;

// Exit if file accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit( 0 );
}

use PressThemes\BuddyCircles\BuddyPress\Circle_Component;
use PressThemes\BuddyCircles\BuddyPress\Circle_Screens;

/**
 * Class Hooks_Helper
 */
class Hooks_Helper {

	/**
	 * Boot itself
	 */
	public static function boot() {
		$self = new self();
		$self->setup();
	}

	/**
	 * Setup hooks
	 */
	private function setup() {
		add_action( 'bp_directory_members_actions', array( $this, 'add_button_in_members_directory' ) );
		// for BuddyBoss theme's members directory.
		add_action( 'bp_member_members_list_item', array( $this, 'add_button_in_members_directory' ) );
		// user header.
		add_action( 'bp_member_header_actions', array( $this, 'add_button_on_profile' ) );

		add_action( 'bp_activity_filter_options', array( $this, 'modify_activity_filters' ), 1001 );
		add_action( 'bp_member_activity_filter_options', array( $this, 'modify_activity_filters' ), 1001 );

		//add_filter( 'bp_ajax_querystring', 'circle_filter_qs', 1000, 2 );
		add_filter( 'bp_after_has_activities_parse_args', array( $this, 'filter_qs_all_circle' ), 100 );
		add_filter( 'bp_after_has_activities_parse_args', array( $this, 'filter_qs_single_circle' ), 100 );

		add_action( 'bp_setup_nav', array( $this, 'add_component_submenu' ), 12 );
		add_action( 'bp_friends_admin_nav', array( $this, 'add_friends_adminbar_menu' ), 0 );

		add_action( 'bp_activity_setup_nav', array( $this, 'add_activity_submenu' ) );
		add_filter( 'bp_activity_admin_nav', array( $this, 'add_activity_adminbar_menu' ), 70 );

		add_action( 'bp_setup_components', array( $this, 'setup_component' ), 6 );

		add_action( 'bp_screens', array( $this, 'single_circle' ) );

		add_action( 'before_circle_users_loop', array( $this, 'attach_parse_args' ) );
		add_action( 'after_circle_users_loop', array( $this, 'detach_parse_args' ) );

		// members directory.
		add_action( 'bp_members_directory_member_types', array( $this, 'add_member_directory_tabs' ) );
		add_filter( 'bp_after_has_members_parse_args', array( $this, 'filter_members_for_directory') );

		//Nouveau.
		add_filter( 'bp_nouveau_get_members_directory_nav_items', array( $this, 'add_member_directory_tabs_nouveau' ) );
	}

	/**
	 * Add button in members directory
	 */
	public function add_button_in_members_directory() {

		if ( apply_filters( 'bcircles_show_button_in_directory', true ) ) {
			bcircles_add_to_circle_button( bp_get_member_user_id() );
		}
	}

	/**
	 * Add button on user profile
	 */
	public function add_button_on_profile() {

		if ( apply_filters( 'bcircles_show_button_on_profile', true ) ) {
			bcircles_add_to_circle_button( bp_displayed_user_id() );
		}
	}

	/**
	 * Modify activity filters
	 */
	public function modify_activity_filters() {

		if ( ! is_user_logged_in() ) {
			return;
		}

		if ( ! bp_is_my_profile() && ! bp_is_activity_directory() ) {
			return;
		}

		$circles = bcircles_get_circle_objects( bcircles_get_user_circles( get_current_user_id(), true, true ) );
		$prefix = __( 'Circle: ', 'buddycircles' );

		foreach ( $circles as $circle ) {
			$label = $prefix . $circle->label;
			$value = "bcircles-{$circle->id}";

			echo '<option value="' . esc_attr( $value ) . '">' . esc_html( $label ) . '</option>';
		}
	}

	/**
	 * Single circle filter of activity
	 *
	 * @param array $args Args.
	 *
	 * @return mixed
	 */
	public function filter_qs_single_circle( $args ) {

		//var_dump( $args );

		if ( empty( $args['type'] ) ) {
			return $args;
		}

		$action = $args['type'];

		if ( false === strpos( $action, 'bcircles-' ) ) {
			return $args;
		}

		$circle_ids = explode( '-', $action );
		$circle_id  = $circle_ids[1];

		$circle_users    = bcircles_get_circle_users( $circle_id );
		$args['user_id'] = $circle_users;

		if ( bp_is_user() ) {
			//array_push( $args['user_id'], bp_displayed_user_id() );
		}

		// Do not show list if empty.
		if ( empty( $args['user_id'] ) ) {
			$args['user_id'] = array( 0, 0 );
		} else {
			// Check if filter is enabled.
			if ( ! empty( $args['filter'] ) ) {
				$args['filter']['user_id'] = $args['user_id'];
			}
		}

		$args['action'] = '';
		$args['type']   = '';

		return $args;
	}

	/**
	 * Filter the activity on the default screen for the activity->circle
	 *
	 * @param array $args Args.
	 *
	 * @return array mixed
	 */
	public function filter_qs_all_circle( $args ) {

		if ( ! bp_is_user_activity() || ! bp_is_current_action( bcircles_get_circle_slug() ) ) {
			return $args;
		}

		$action = isset( $args['type'] ) ? $args['type'] : '';

		if ( false !== strpos( $action, 'bcircles-' ) ) {
			return $args;
		}

		$circle_ids = bcircles_get_user_circles( bp_displayed_user_id(), true, true );

		if ( empty( $circle_ids ) ) {
			$args['user_id'] = array( 0, 0 );
			return $args;
		}

		$circle_users = bcircles_get_users_for_all_circles( $circle_ids );

		$args['user_id'] = $circle_users;

		if ( bp_is_user() ) {
			//array_push( $args['user_id'], bp_displayed_user_id() );
		}

		// Do not show list if empty.
		if ( empty( $args['user_id'] ) ) {
			$args['user_id'] = array( 0, 0 );
		} else {
			// Check if filter is enabled.
			if ( ! empty( $args['filter'] ) ) {
				$args['filter']['user_id'] = $args['user_id'];
			}
		}

		$args['action'] = '';
		$args['type']   = '';

		return $args;
	}

	/**
	 * Add admin bar menu
	 *
	 * @param array $nav Nav array.
	 *
	 * @return array
	 */
	public function add_friends_adminbar_menu( $nav = array() ) {

		$parent_component = bcircles_get_parent_component_slug();

		if ( ! is_user_logged_in() || 'friends' != $parent_component ) {
			return $nav;
		}

		// Setup the logged in user variables. should this constant will available.
		$user_domain = bp_loggedin_user_domain();
		$link        = trailingslashit( $user_domain . bp_get_friends_slug() . '/' . bcircles_get_circle_slug() );
		$title       = __( 'Circles', 'buddycircles' );

		$nav[] = array(
			'parent'   => 'my-account-friends',
			'id'       => 'my-account-friends-circle',
			'title'    => $title,
			'href'     => trailingslashit( $link ),
			'position' => 35,
		);

		return $nav;
	}

	/**
	 * Add friends subnav item
	 */
	public function add_component_submenu() {

		$parent_slug = bcircles_get_parent_component_slug();

		if ( ! $parent_slug ) {
			return;
		}

		$user_domain = bp_is_my_profile() ? bp_loggedin_user_domain() : bp_displayed_user_domain();
		$screen      = new Circle_Screens();

		$sub_nav = array(
			'name'            => __( 'Circles', 'buddycircles' ),
			'slug'            => bcircles_get_circle_slug(),
			'parent_slug'     => $parent_slug,
			'parent_url'      => trailingslashit( $user_domain . $parent_slug ),
			'screen_function' => array( $screen, 'circles' ),
			'position'        => 34,
			'user_has_access' => true,
		);

		bp_core_new_subnav_item( $sub_nav );
	}

	/**
	 * Add menu in activity
	 *
	 * @param array $nav Array.
	 *
	 * @return array
	 */
	public function add_activity_adminbar_menu( $nav = array() ) {

		if ( ! is_user_logged_in() || ! is_array( $nav ) ) {
			return $nav;
		}

		// Setup the logged in user variables.
		$user_domain = bp_loggedin_user_domain();
		$link        = trailingslashit( $user_domain . bp_get_activity_slug() . '/' . bcircles_get_circle_slug() );

		$nav[] = array(
			'parent'   => 'my-account-activity',
			'id'       => 'my-account-activity-circle',
			'title'    => __( 'Circles', 'buddycircles' ),
			'href'     => trailingslashit( $link ),
			'position' => 45,
		);

		return $nav;
	}

	/**
	 * Add friends subnav item
	 */
	public function add_activity_submenu() {

		$user_domain   = ( bp_is_my_profile() ) ? bp_loggedin_user_domain() : bp_displayed_user_domain();
		$screen        = new Circle_Screens();
		$activity_slug = bp_get_activity_slug();

		$sub_nav = array(
			'name'            => __( 'Circles', 'buddycircles' ),
			'slug'            => bcircles_get_circle_slug(),
			'parent_slug'     => $activity_slug,
			'parent_url'      => trailingslashit( $user_domain . $activity_slug ),
			'screen_function' => array( $screen, 'activity_circles' ),
			'position'        => 34,
			'user_has_access' => bp_is_my_profile() || is_super_admin(),
		);

		bp_core_new_subnav_item( $sub_nav );
	}

	/**
	 * Single circle screen
	 */
	public function single_circle() {

		$component = bcircles_get_circle_slug();
		$slug_base = 'circle';

		if ( ! bp_is_current_component( $component ) || ! bp_is_current_action( $slug_base ) || ! bp_action_variable( 0 ) ) {
			return;
		}

		$screen = new Circle_Screens();
		$screen->circles();
	}

	/**
	 * Setup buddypress component
	 */
	public function setup_component() {
		buddypress()->circle = new Circle_Component();
	}

	/**
	 * Filter Query args.
	 *
	 * @param array $args Args.
	 *
	 * @return mixed
	 */
	public function filter_members( $args ) {

		$args['user_id'] = '';
		$circle          = bcircles_get_circle( bp_action_variable( 0 ) );
		$args['include'] = bcircles_get_circle_users( $circle->id );
		if ( empty( $args['include'] ) ) {
			$args['include'] = array( 0, 0 );
		}

		remove_filter( 'bp_after_has_members_parse_args', array( $this, 'filter_members' ), 100 );

		return $args;
	}

	/**
	 * Filter members list for directory.
	 *
	 * @param array $args args.
	 *
	 * @return array
	 */
	public function filter_members_for_directory( $args ) {
		// Let us not filter args in admin.
		if ( ! bcircles_get_option( 'enable_directory_tabs', 0 ) || is_admin() && ! defined( 'DOING_AJAX' ) || isset( $args['context'] ) ) {
			return $args;
		}

		$scope = isset( $args['scope'] ) ? wp_unslash( $args['scope'] ) : null;

		if ( empty( $scope ) && ! empty( $_POST['scope'] ) ) {
			$scope = trim( wp_unslash( $_POST['scope'] ) );
		}

		if ( empty( $scope ) ) {
			return $args;
		}

		// filter member type.
		if ( ! empty( $scope ) && substr( $scope, 0, 7 ) === 'bcircle' ) {
			$circle_id       = str_replace( 'bcircle', '', $scope );
			$args['include'] = bcircles_get_circle_users( (int) $circle_id );

			if ( empty( $args['include'] ) ) {
				$args['include'] = array( 0, 0 );
			}
			$args['scope'] = false; // unset.
		}

		return $args;
	}

	/**
	 * Show the members tab.
	 */
	public function add_member_directory_tabs() {

		if ( function_exists( 'bp_nouveau' ) ) {
			return;
		}

		if ( ! is_user_logged_in() || ! apply_filters( 'bcircles_show_members_directory_tabs', bcircles_get_option( 'enable_directory_tabs', 0 ) ) ) {
			return;
		}

		$circles = bcircles_get_circle_objects( bcircles_get_user_circles( get_current_user_id(), true, true ) );

		if ( empty( $circles ) ) {
			return;
		}

		foreach ( $circles as $circle ) {
			$url       = esc_url( bcircles_get_single_circle_screen_url( $circle->id ) );
			$label     = esc_html( $circle->label );
			$circle_id = esc_attr( $circle->id );
			echo "<li id='members-bcircle{$circle_id}'><a href='{$url}'>{$label}</a></li>";
		}
	}

	/**
	 * Show the members tab.
	 */
	public function add_member_directory_tabs_nouveau( $nav_items ) {

		if ( ! is_user_logged_in() || ! apply_filters( 'bcircles_show_members_directory_tabs', bcircles_get_option( 'enable_directory_tabs', 0 ) ) ) {
			return $nav_items;
		}

		$circles = bcircles_get_circle_objects( bcircles_get_user_circles( get_current_user_id(), true, true ) );

		if ( empty( $circles ) ) {
			return $nav_items;
		}

		foreach ( $circles as $circle ) {
			$nav_items["members-bcircle{$circle->id}"] = array(
				'component' => 'members',
				'slug'      => "bcircle{$circle->id}",
				// slug is used because BP_Core_Nav requires it, but it's the scope
				'li_class'  => array(),
				'link'      => esc_url( bcircles_get_single_circle_screen_url( $circle->id ) ),
				'text'      => esc_html( $circle->label ),
				'count'     => count( bcircles_get_circle_users( $circle->id ) ),
				'position'  => 19,
			);

			//echo "<li id='members-bcircle{$circle->id}'><a href='{$url}'>{$circle->label}</a></li>";
		}

		return $nav_items;
	}

	/**
	 * Attach the hook.
	 */
	public function attach_parse_args() {
		add_filter( 'bp_after_has_members_parse_args', array( $this, 'filter_members' ), 100 );
	}

	/**
	 * Detach the args hook.
	 */
	public function detach_parse_args() {
		remove_filter( 'bp_after_has_members_parse_args', array( $this, 'filter_members' ), 100 );
	}
}
