<?php
/**
 * Buddy Circle Database Schema helper
 *
 * @package    BuddyCircles
 * @subpackage Schema
 * @copyright  Copyright (c) 2018, Brajesh Singh
 * @license    https://www.gnu.org/licenses/gpl.html GNU Public License
 * @author     Ravi Sharma, Brajesh Singh
 * @since      1.0.0
 */

namespace PressThemes\BuddyCircles\Schema;

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Buddy Circle Schema Manager.
 */
class Schema {

	/**
	 * Get table name.
	 *
	 * @param string $name table identifier.
	 *
	 * @return null|string full table name or null.
	 */
	public static function table( $name ) {

		global $wpdb;

		$tables = array(
			'circles'         => 'bcircles_user_circles',
			'members'         => 'bcircles_circle_members',
		);

		return isset( $tables[ $name ] ) ? $wpdb->prefix . $tables[ $name ] : null;
	}

	/**
	 * Create Tables.
	 */
	public static function create() {

		global $wpdb;

		require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );

		$charset_collate = $wpdb->get_charset_collate();

		$table_circles        = self::table( 'circles' );
		$table_circle_members = self::table( 'members' );

		$sql = array();

		if ( ! self::exists( $table_circles ) ) {
			$sql[] = "CREATE TABLE `{$table_circles}` (
		  		`id` bigint(20) NOT NULL AUTO_INCREMENT PRIMARY KEY,
		  		`label` varchar(128) NOT NULL,
		  		`user_id` bigint(20) NOT NULL,
		  		`privacy` varchar(32) NOT NULL
			) {$charset_collate};";
		}

		if ( ! self::exists( $table_circle_members ) ) {
			$sql[] = "CREATE TABLE `{$table_circle_members}` (
		  		`id` bigint(20) NOT NULL AUTO_INCREMENT PRIMARY KEY,
		  		`circle_id` bigint(20) NOT NULL,
		  		`user_id` bigint(20) NOT NULL,
		  		`modified_at` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
			) {$charset_collate};";
		}

		if ( ! $sql ) {
			return;
		}

		dbDelta( $sql );
	}

	/**
	 * On uninstall callback
	 */
	public static function drop() {

	}

	/**
	 * Check if table exists.
	 *
	 * @param string $table_name table name.
	 *
	 * @return bool
	 */
	public static function exists( $table_name ) {
		global $wpdb;

		return $wpdb->get_var( $wpdb->prepare( "SHOW TABLES LIKE %s", $table_name ) ) === $table_name;
	}
}
